# -*-mode: fundamental; coding: utf-8;-*-
# UTF-8 encoded Swedish language file for use with Oddmuse
#
# Copyright (c) 2003 Erik S-O Johansson and others
# Copyright (c) 2003 Björn Lindström <bkhl@elektrubadur.se> and
#                    Zrajm C Akfohg <zrajm@klingonska.org>
# Copyright (c) 2004-06 Johan Adler <alltid@nyfiken.org>
# Copyright (c) 2004 Zrajm C Akfohg <zrajm@klingonska.org>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: swedish-utf8.pl,v 1.15 2006/05/10 22:52:16 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Läsning inte tillåten: användare, ip eller nätverk är blockerat.
Could not create %s
Kunde inte skapa %s
Invalid UserName %s: not saved.
Ogiltigt användarnamn %s: Ej sparad.
UserName must be 50 characters or less: not saved
Användarnamn får bestå av högst 50 tecken: Ej sparad.
This page contains an uploaded file:
Denna sida innehåller en uppladdad fil:
Recursive include of %s!

XML::RSS is not available on this system.
XML::RSS inte tillgängligt på det här systemet.
diff
ändringar
history
historik
%s returned no data, or LWP::UserAgent is not available.
Antingen returnerade %s inget data, eller så finns inte LWP::UserAgent tillgängligt.
RSS parsing failed for %s
Misslyckades med RSS-tolkningen av %s
No items found in %s.
Ingen information funnen i %s.
 . . . . 

Click to edit this page
Klicka för att redigera den här sidan
image
bild
download
ladda ned
CGI Internal error: %s
Internt CGI-fel: %s
Invalid action parameter %s
Ogiltig parameter %s
Invalid URL.
Ogiltig URL.
Page name is missing
Sidnamn saknas
Page name is too long: %s
Sidnamn är för långt: %s
Invalid Page %s (must not end with .db)
Ogiltig sida %s (får inte sluta med .db)
Invalid Page %s (must not end with .lck)
Ogiltig sida %s (får inte sluta med .lck)
Invalid Page %s
Ogiltig sida %s
Preview:
Förhandsgranskning:
Preview only, not yet saved
Endast förhandsgranskning, ännu inte sparad
Please go on to %s.
Gå vidare till %s.
Could not open %s log file
Kunde inte öppna %s-loggen
Error was
Felet var
Note: This error is normal if no changes have been made.
Observera: Det här felet är normalt om inga ändringar gjorts.
Could not open old %s log file
Kunde inte öppna gammal %s-loggfil
No updates since %s
Inga ändringar sedan %s
Updates since %s
Ändringar sedan %s
Updates in the last %s days
Ändringar de %s senaste dagarna
Updates in the last %s day
Ändringar den %s senaste dagen
for %s only
för endast %s
List latest change per page only
Visa bara senaste ändring för varje sida
List all changes
Visa alla ändringar
List only major changes
Visa bara stora ändringar
Include minor changes
Visa små ändringar också
%s days
%s dagar
List later changes
Visa senare ändringar
Filters
Sålla
Title:
Titel:
Title and Body:
Titel och innehåll:
Username:
Användare:
Host:
Värddator:
Language:
Språk
Go!
Utför
(minor)
(mindre)
rollback
återställning
new
ny
from %s
från %s
This page is too big to send over RSS.
Denna sida är för stor för att sändas över RSS.
History of %s
Historik för %s
Compare
Jämför
Revision %s
Version %s
by
av
Rolling back changes
Återställer
Missing target for rollback.
Mål för återställning saknas.
Target for rollback is too far back.
Mål för återställning för gammalt.
Rollback to %s
Återställning till %s
%s rolled back
%s återställd
Index of all pages
Innehållsförteckning
Wiki Version
Wikiversion
Unlock Wiki
Lås upp wiki
Password
Lösenord
Run maintenance
Utför underhåll
Unlock site
Lås upp wikin
Lock site
Lås wikin
Install CSS
Installera CSS
Unlock %s
Lås upp %s
Lock %s
Lås %s
Administration

Actions:
Verktyg:
Important pages:
Viktiga sidor:
To mark a page for deletion, put <strong>%s</strong> on the first line.
För att markera en sida för radering, skriv <strong>%s</strong> på första raden.
[Home]
[Startsida]
redirected from %s
omdirigerad från %s
Click to search for references to this page
Klicka för att söka efter referenser till den här sidan
Cookie: 

Warning
Varning
Database is stored in temporary directory %s
Databas sparad i tillfällig katalog %s
%s seconds
%s sekunder
The same page on other sites:
Samma sida på andra siter:
EditNearLinks
Redigera närlänkar
Last edited
Senast ändrad
Edited
Redigerad
by %s
av %s
(diff)
(ändringar)
Edit revision %s of this page
Redigera version %s av den här sidan
Edit this page
Redigera sidan
e
r
This page is read-only
Sidan är skrivskyddad
View other revisions
Visa andra versioner
View current revision
Visa rådande version
View all changes
Visa alla ändringar
Homepage URL:
URL till hemsida:
s
s
Save
Spara
p
f
Preview
Förhandsgranska
Search:
Sök:
f
k
Replace:
Ersätt:
Validate HTML
Validera HTML
Validate CSS
Validera CSS
Difference (from revision %1 to %2)
Skillnad (från version %1 till %2)
revision %s
version %s
current revision
rådande version
Difference (from prior %s revision)
Förändring (sedan senaste %s version)
major
stora
minor
mindre
No diff available.
Information om ändring är inte tillgänglig.
The two revisions are the same.
De två versionerna är identiska.
Old revision:
Gammal version:
Changed:
Ändrad:
Removed:
Borttagen:
Added:
Tillagd:
to
till
Revision %s not available
Version %s inte tillgänglig
showing current revision instead
visar rådande version istället
Showing revision %s
Det här är version %s
Cannot save a nameless page.
Kan inte spara en namnlös sida.
Cannot save a page without revision.
Kan inte spara en sida utan ändringar.
Cannot open %s
Kan inte öppna %s
Cannot write %s
Kan inte skriva %s
Cannot create %s
Kan inte skapa %s
Could not get %s lock
Kunde inte låsa %s
The lock was created %s.
Låset skapades %s.
This operation may take several seconds...
Den här funktionen kan ta flera sekunder...
Forced unlock of %s lock.
Forcerad upplåsning av %s.
No unlock required.
Ingen upplåsning behövs.
%s hours ago
för %s timmar sedan
1 hour ago
för 1 timme sedan
%s minutes ago
för %s minuter sedan
1 minute ago
för 1 minut sedan
%s seconds ago
för %s sekunder sedan
1 second ago
för 1 sekund sedan
just now
just nu
Edit Denied
Redigering nekas
Editing not allowed: user, ip, or network is blocked.
Redigering inte tillåten: användare, ip-adress eller nätverk är blockerat.
Contact the wiki administrator for more information.
Kontakta wiki-administratören för mer information.
The rule %s matched for you.
Regeln %s passar in på dig.
See %s for more information.
Se %s för mer information.
Editing not allowed: %s is read-only.
Redigering är inte tillåten: %s är skrivskyddad.
Only administrators can upload files.
Endast administratörer kan ladda upp filer.
Editing revision %s of
Redigerar version %s av
Editing %s
Redigerar %s
Editing old revision %s.
Redigerar gammal version %s.
Saving this page will replace the latest revision with this text.
Att spara den här sidan kommer att ersätta den senaste versionen med den här texten.
Summary:
Sammanfattning:
This change is a minor edit.
Det här är en mindre ändring.
Replace this file with text.
Skriv text istället för den här filen.
Replace this text with a file.
Använd en fil i stället för den här texten.
File to upload: 
Fil att ladda upp: 
Files of type %s are not allowed.
Filer av typen %s är inte tillåtna.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ditt lösenord sparas i en cookie om du har cookies påslagna. Cookies kan försvinna om du ansluter från en annan dator, från ett annat konto eller med ett annat program.
You are currently an administrator on this site.
Du är för närvarande administratör för den här webbplatsen.
You are currently an editor on this site.
Du är för närvarande redaktör för den här webbplatsen.
You are a normal user on this site.
Du är en normal användare på den här webbplatsen.
Your password does not match any of the  administrator or editor passwords.
Ditt lösenord motsvarar inget av admininistratörs- eller redaktörslösenorden.
Password:
Lösenord:
This site does not use admin or editor passwords.
Den här webbplatsen använder inte administratörs- eller redaktörslösenord.
This operation is restricted to site editors only...
Den här funktionen kan bara utföras av redaktörer...
This operation is restricted to administrators only...
Den här funktionen kan bara utföras av adminstratörer...
Rule "%1" matched "%2" on this page.
Regel "%1"  matchade "%2" på denna sida.
Without normal pages
Utan vanliga sidor
Include normal pages
Med vanliga sidor
Without permanent anchors
Utan permanenta ankare
Include permanent anchors
Med permanenta ankare
Without near pages
Utan nära sidor
Include near pages
Med nära sidor
(for %s)
(för: %s)
Filter:

%s pages found.
%s sidor.
Replaced: %s
Ersatt: %s
Search for: %s
Sök efter: %s
View changes for these pages
Se ändringar för dessa sidor
Search sites on the %s as well
Sök siter på %s också
and
och
or
eller
Fetching results from %s:
Hämtar resultat från %s:
Near pages:
Nära sidor:
last updated
senast reviderad
Complete Content
Fullständigt innehåll
The main page is %s.
Huvudsidan är %s.
Comments on this page
Kommenterarer till denna sida
Editing not allowed for %s.
%s kan inte redigeras.
SampleUndefinedPage
OdefinieradExempelsida
%s cannot be defined.
%s kan inte definieras.
Sample_Undefined_Page
Odefinierad_exempelsida
[[%s]] cannot be defined.
[[%s]] kan inte definieras.
Only an administrator can create %s.
Endast en administratör kan skapa %s.
Transfer Error: %s
Överföringsfel: %s
Browser reports no file info.
Webbläsare rapporterar ingen filinformation.
Browser reports no file type.
Webbläsare rapporterar ingen filtyp.
The page contains banned text.
Sidan innehåller otillåten text.
No changes to be saved.
Inga ändringar att spara.
This page was changed by somebody else %s.
Den här sidan ändrades av någon annan %s.
The changes conflict.  Please check the page again.
Ändringarna står i konflikt. Kontrollera sidan igen.
Please check whether you overwrote those changes.
Kontrollera om du skrev över de ändringarna.
Anonymous
Anonym
Cannot delete the index file %s.
Kan inte radera index-filen %s.
Please check the directory permissions.
Vänligen kontrollera biblioteksrättigheter.
Your changes were not saved.
Dina ändringar har inte sparats.
Could not get a lock to merge!
Kunde inte låsa för att slå samman!
you
du
ancestor
förfader
other
annan
Run Maintenance
Utför underhåll
Maintenance not done.
Underhåll ej slutfört.
(Maintenance can only be done once every 12 hours.)
(Underhåll kan bara utföras en gång var 12:e timme.)
Remove the "maintain" file or wait.
Ta bort "maintain"-filen eller vänta.
Main lock obtained.
Huvudlås påslaget.
Expiring keep files and deleting pages marked for deletion
Avlägsnar "keep"-filer och raderar sidor märkta för radering
not deleted: 
ej borttagen:
deleted
borttagen
Moving part of the %s log file.
Flyttar del av %s-loggen.
Moving %s log entries.
Flyttar %s loggnotering.
Getting page index file for %s.
Hämtar sidindexfil för %s.
Main lock released.
Huvudlås avslaget.
Set or Remove global edit lock
Slå på eller av globalt redigeringslås
Edit lock created.
Redigeringslås påslaget.
Edit lock removed.
Redigeringslås avslaget.
Set or Remove page edit lock
Slå på eller av sidredigeringslås
Lock for %s created.
Slog på redigeringslås för %s.
Lock for %s removed.
Slog av redigeringslås för för %s.
Displaying Wiki Version
Visar Wikiversion
Show dependencies
Visa beroenden
Inter links:
Interlänkar:
Near links:
Närlänkar:
Show parsed link data
Visa tolkat länkdata
Too many connections by %s
För många anslutningar ifrån %s
Please do not fetch more than %1 pages in %2 seconds.
Vänligen hämta inte mer än %1 sidor på %2 sekunder.
Check whether the web server can create the directory %s and whether it can create files in it.
Kontrollera att webservern kan skapa biblioteket %s och att den kan skapa filer i det.
anchor first defined here: %s
ankare definierades först här: %s
Click to search for references to this permanent anchor
Klicka för att söka efter referenser till det här permanenta ankaret
the page %s also exists
sidan %s finns också
Copy one of the following stylesheets to %s:
Kopiera en av följande 'stylesheets' till %s:
Deleting %s
Tar bort %s
Deleted %s
Tog bort %s
Renaming %1 to %2.
Byter namn på %1 till %2.
The page %s does not exist
Sidan %s finnes inte
The page %s already exists
Sidan %s finns redan
Cannot rename %1 to %2
Kan inte byta namn på %1 till %2
Renamed to %s
Bytt namn till %s
Renamed from %s
Bytt namn från %s
Renamed %1 to %2.
Bytt namn på %1 till %2.
Immediately delete %s
Radera %s direkt
Rename %s to:
Byt namn på %s till:
Learn more...
Läs mer...
Cannot highlight the language %s.
Kan ej markera språket %s.
Recent Visitors
Senaste besökare
some action
gjorde något
was here
var här
and read
och läste
Illegal year value: Use 0001-9999

The match parameter is missing.
Parametern "match" saknas.
Page Collection for %s
Sidsamling för %s
Previous
Föregående
Next
Nästa
Calendar %s
Kalender %s
Su
Sö
Mo
Må
Tu
Ti
We
On
Th
To
Fr

Sa
Lö
January
januari
February
februari
March
mars
April
april
May
maj
June
juni
July
juli
August
augusti
September
september
October
oktober
November
november
December
december
Clustermap
Klusterkarta
Pages without a Cluster
Sidor utan kluster
Comments on 
Kommentarer till 
Comment on 
Kommentar till 
Compilation for %s
Sammanställning för %s
Compilation tag is missing a regular expression.
Sammanställnings-taggen saknar en "regular expression".
Despamming pages
Rensar sidor från skräptexter
Cannot find revision %s.
Kan inte hitta version %s.
Revert to revision %1: %2
Återställer till version %1: %2
Marked as %s.
Markerad som %s.
Cannot find unspammed revision.
Kan inte finna version utan skräptexter
Add Comment
Lägg till kommentar
ordinary changes
vanliga ändringar
Footnotes:
Fotnoter:
Could not find %1.html template in %2
Kunde inte finna %1.html-mallen i %2
Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index
Innehållsförteckning
Languages:
Språk:
Show!
Visa!
Define
Definiera
Full Link List
Fullständing länklista
Template without parameters
Mall utan parametrar
The template %s is either empty or does not exist.
Mallen %s är antingen tom eller saknas.
 -- defined on %s
 -- definierad på %s
Local names defined on %1: %2
Lokala namn definierade på %1: %2
Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache
Rensar cachen
Done.
Färdig.
Generating Link Database
Skapar länkdatabas
The 404 handler extension requires the link data extension (links.pl).
404-hanterarmodulen kräver länkdatamodulen för att fungera (links.pl).
LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List
Lista över övergivna sidor
Trail: 
Senast: 
None
Inga
Type
Sort
Permalink to "%s"
Permanentlänk till "%s"
There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait
Porträtt
You did not answer correctly.
Du svarade inte korrekt.
All Referrers
Alla som länkat hit
Referrers
Sidor som länkat hit
Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.
Sökord saknas.
Result pages: 

(%s results)

Slideshow:%s

Static Copy
Statisk kopia
Back to %s
Tillbaka till %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:
Eller använd en av följande mallar:
Thread: %s
Tråd: %s
ID parameter is missing.
ID-parametern saknas.
Thread %s does not exist.
Tråden %s finns inte.
Page %s does not contain a thread.
Sidan %s innehåller ingen tråd.
Add
Lägg till
URL parameter is missing.
URL-parametern saknas.
Add to %s thread
Lägg till till %s-tråden
Below:
Nedan:
URL:
URL:
Name:
Namn:
Failed to remove %s
Misslyckades med att ta bort %s
Contents
Innehåll
This page is a translation of %s. 
Denna sida är en översättning av %s. 
The translation is up to date.
Denna översättning är aktuell.
The translation is outdated.
Denna översättning är föråldrad
The page does not exist.
Sidan finns inte.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativ
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://www.bokpris.com/%s
search
sök
Upload of %s file

Blog
Blogg
Matching pages:

New

Edit %s.

END_OF_TRANSLATION
